%define major 7
%define inchi_major 0
%define coordgen_major 1
%define maeparser_major 1
%define libname %mklibname %{name} %{major}
%define inchilib %mklibname inchi %{inchi_major}
%define libcoordgen %mklibname coordgen %{coordgen_major}
%define libmaeparser %mklibname maeparser %{maeparser_major}
%define devname %mklibname %{name} -d

Summary:	Chemistry software file format converter
Name:		openbabel
Version:	3.1.1
Release:	1
License:	GPLv2+
Group:		Sciences/Chemistry
Url:		http://openbabel.org
#               https://github.com/openbabel/openbabel/releases/download/openbabel-3-1-1/openbabel-3.1.1-source.tar.bz2
Source0:        https://github.com/openbabel/openbabel/releases/download/%{name}-%(echo %{version} | tr '.' '-')/%{name}-%{version}-source.tar.bz2
Source1:	openbabelgui.desktop
# Missing file: data/ring-fragments-index.txt #2613
# https://github.com/openbabel/openbabel/issues/2613
Source2:        ring-fragments-index.txt

# Fix some warnings CMakeLists.txt
Patch1:		%{name}-cmakelists.patch
# Fix plugin directory location (#680292, patch by lg)
Patch2:		%{name}-plugindir.patch
# Fix UB in UFF parameter parsing. Bug 2224
Patch3:		%{name}-bug2224.patch
# Fix perl modules install path and 1 warning
Patch4:		%{name}-perl.patch
# Fix test failure with Python 3
Patch5:		%{name}-python-bug2217.patch
# Fix coordgenlibs
Patch6:		%{name}-coordgenlibs.patch
# Fix Maeparser
Patch7:		%{name}-maeparser.patch
#Patch8: 	arm-build.patch

BuildRequires:	cmake
BuildRequires:	eigen3
BuildRequires:	libtool
BuildRequires:  doxygen
BuildRequires:	swig
BuildRequires:	perl-devel
BuildRequires:	ruby-devel
BuildRequires:	wxgtku3.2-devel
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(python3)
BuildRequires:	perl(ExtUtils::MakeMaker)

%description
Open Babel is a project designed to pick up where Babel left off,
as a cross-platform program and library designed to interconvert
between many file formats used in molecular modeling and computational
chemistry.

%files
%doc AUTHORS COPYING THANKS
%doc doc/*.html doc/diox* doc/README*
%{_bindir}/*
%{_mandir}/man?/*
%{_datadir}/%{name}
%{_libdir}/%{name}

#----------------------------------------------------------------------------

%package -n %{libname}
Summary:	Shared libraries of %{name}
Group:		System/Libraries

%description -n %{libname}
Open Babel is a project designed to pick up where Babel left off,
as a cross-platform program and library designed to interconvert
between many file formats used in molecular modeling and computational
chemistry.

This package contains shared libraries of %{name}.

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}*

#----------------------------------------------------------------------------

%package -n %{inchilib}
Summary:	Shared libraries of inchi
Group:		System/Libraries

%description -n %{inchilib}
The IUPAC International Chemical Identifier (InChITM) is a non-proprietary
identifier for chemical substances that can be used in printed and
electronic data sources thus enabling easier linking of diverse data
compilations. It was developed under IUPAC Project 2000-025-1-800 during
the period 2000-2004. Details of the project and the history of its
progress are available from the project web site.

This package contains shared libraries of inchi.

%files -n %{inchilib}
%{_libdir}/libinchi.so.%{inchi_major}*

#----------------------------------------------------------------------------

%package -n %{libcoordgen}
Summary:	Shared libraries of coordgenlibs
Group:		System/Libraries

%description -n %{libcoordgen}
This is Schrödinger, Inc's 2D coordinate generation. It was formerly
proprietary code, but is now released under the BSD license. The emphasis
of these algorithms are on quality of 2D coordinates rather than speed of
generation. The algorithm distinguishes itself from many others by doing
well with both macrocycles and metal complexes. It also does extremely
well on typical drug-like small molecules, and has been validated on
millions of compounds.

This package contains shared libraries of coordgenlibs.

%files -n %{libcoordgen}
%doc README.md
%{_libdir}/libcoordgen.so.*
%{_libdir}/cmake/coordgenlibs/*

#----------------------------------------------------------------------------

%package -n %{libmaeparser}
Summary:	Shared libraries of maeparser
Group:		System/Libraries

%description -n %{libmaeparser}
Maeparser is a parser for Schrodinger Maestro files. Structure files
(.mae,.maegz,.mae.gz) can contain multiple structures delimited by
"f_m_ct". In supporting Schrödinger's backend suite, maeparser is able
to handle output from:
- Molecular Dynamics applications, such as Desmond and FEP+
- Ligand-Protein Docking applications, such as Glide
- Homology Modeling and folding applications, such as Prime
- Ligand-based search applications, such as Phase and Phase Shape
- Quantum Mechanics applications, such as Jaguar
- Protein-Protein Docking applications
- Many other backends used in both Life and Material Sciences

This package contains shared libraries of maeparser.

%files -n %{libmaeparser}
%doc README.md
%{_libdir}/libmaeparser.so.*
%{_libdir}/cmake/maeparser/*

#----------------------------------------------------------------------------

%package -n %{devname}
Summary:	Development files of %{name}
Group:		Development/C++
Requires:	%{libname} = %{EVRD}
Requires:	%{inchilib} = %{EVRD}
Provides:	%{name}-devel = %{EVRD}

%description -n %{devname}
Open Babel is a project designed to pick up where Babel left off,
as a cross-platform program and library designed to interconvert
between many file formats used in molecular modeling and computational
chemistry.

This package includes the header files and other development
related files necessary for developing or compiling programs
using the %{name} library.

%files -n %{devname}
%{_includedir}/*
%{_libdir}/cmake/openbabel3/*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/lib*.so

#----------------------------------------------------------------------------

%package -n perl-%{name}
Summary:	Perl wrapper for the Open Babel library
Group:		Development/Perl

%description -n perl-%{name}
Perl wrapper for the Open Babel library.

%files -n perl-%{name}
%{perl_vendorarch}/*

#----------------------------------------------------------------------------

%package -n python-%{name}
Summary:	Python wrapper for the Open Babel library
Group:		Development/Python

%description -n python-%{name}
Python wrapper for the Open Babel library.

%files -n python-%{name}
%{python3_sitearch}/*

#----------------------------------------------------------------------------

%if 0
%package -n ruby-%{name}
Summary:	Ruby wrapper for the Open Babel library
Group:		Development/Ruby
Requires:	%{name} = %{EVRD}

%description -n ruby-%{name}
Ruby wrapper for the Open Babel library.

%files -n ruby-%{name}
%{ruby_sitearchdir}/openbabel.so
%endif

#----------------------------------------------------------------------------

%prep
%setup -q -n %{name}-%{version}
%autopatch -p1

%build
%ifarch %{e2k}
LDFLAGS='%{ldflags} -ltirpc'
%endif
%cmake \
        -DWITH_MAEPARSER:BOOL=ON \
        -DWITH_COORDGEN:BOOL=ON \
	-DENABLE_TESTS:BOOL=OFF \
	-DBUILD_GUI:BOOL=ON \
	-DENABLE_VERSIONED_FORMATS=false \
	-DPYTHON_BINDINGS:BOOL=ON \
	-DPYTHON_EXECUTABLE=%{__python3} \
	-DPERL_BINDINGS:BOOL=ON \
	-DRUBY_BINDINGS:BOOL=OFF \
	-DRUN_SWIG=ON \
        -DBUILD_DOCS=ON \
	-DOPENBABEL_USE_SYSTEM_INCHI=OFF
%make -s

%install
%makeinstall_std -C build
install -p -D -m 644 %{SOURCE2} $RPM_BUILD_ROOT/usr/share/openbabel/3.1.1/
